@@ -2,7 +2,8 @@
 """ Google Earth Engine Landsat Collections """
 from .visualization import *
 from .datasets import OpticalSatellite, ImageCollection
-from .bands import OpticalBand, BitBand, ClassificationBand, ExpressionBand
+from .bands import OpticalBand, BitBand, ClassificationBand, ExpressionBand,\
+    Precisions
 from .helpers import TODAY
 from functools import partial
 from . import register
@@ -70,7 +71,7 @@ class Tier2:
 
 
 class RAW:
-    _extra = dict(precision='uint8')
+    _extra = dict(precision='uint8', scale=1/255)
     process = 'RAW'
 
 
@@ -89,13 +90,13 @@ def atm_op_decoder(image):
 
 
 class SR:
-    _extra = dict(scale=0.0001, precision='int16')
+    _extra = dict(scale=0.0001, precision=Precisions.int16)
     process = 'SR'
 
     atm_op = ClassificationBand(
         name='sr_atmos_opacity',
         alias='atmos_opacity',
-        precision='int16',
+        precision=Precisions.int16,
         resolution=30,
         classes= dict(
             clear= 'value<0.1',
@@ -112,7 +113,7 @@ class SR:
     sr_cloud_qa = BitBand(
         name='sr_cloud_qa',
         alias='cloud_qa',
-        precision='uint8',
+        precision=Precisions.uint8,
         resolution=30,
         bits={
             '0': {1:'ddv'},
@@ -128,7 +129,7 @@ class SR:
     pixel_qa = BitBand(
         name='pixel_qa',
         alias='pixel_qa',
-        precision='uint16',
+        precision=Precisions.uint16,
         resolution=30,
         bits={'1': {1:'clear'}, '2': {1:'water'},
               '3': {1:'shadow'}, '4': {1:'snow'},
@@ -144,7 +145,7 @@ class SR:
     radsat_qa = BitBand(
         name='radsat_qa',
         alias='radsat_qa',
-        precision='uint8',
+        precision=Precisions.uint8,
         resolution=30,
         bits={
             1: {1:'B1_saturated'},
@@ -163,15 +164,19 @@ class SR:
 
 class MSS:
     sensor = 'MSS'
-    green = partial(OpticalBand, alias='green', resolution=60, units='DN', wavelength=(0.5, 0.6))
-    red = partial(OpticalBand, alias='red', resolution=60, units='DN', wavelength=(0.6, 0.7))
-    nir = partial(OpticalBand, alias='nir', resolution=60, units='DN', wavelength=(0.7, 0.8))
-    nir2 = partial(OpticalBand, alias='nir2', resolution=30, units='DN', wavelength=(0.8, 1.1))
+    green = partial(OpticalBand, alias='green', resolution=60,
+                    units='DN', wavelength=(0.5, 0.6))
+    red = partial(OpticalBand, alias='red', resolution=60,
+                  units='DN', wavelength=(0.6, 0.7))
+    nir = partial(OpticalBand, alias='nir', resolution=60,
+                  units='DN', wavelength=(0.7, 0.8))
+    nir2 = partial(OpticalBand, alias='nir2', resolution=30,
+                   units='DN', wavelength=(0.8, 1.1))
 
     bqa = BitBand(
         name='BQA',
         alias='bqa',
-        precision='uint16',
+        precision=Precisions.uint16,
         resolution=60,
         bits={'4': {1: 'cloud'}},
         negatives=['cloud']
@@ -181,16 +186,23 @@ class MSS:
 
 class TM:
     sensor = 'TM'
-    blue = partial(OpticalBand, 'B1', 'blue', resolution=30, wavelength=(0.45, 0.52))
-    green = partial(OpticalBand, 'B2', 'green', resolution=30, wavelength=(0.52, 0.6))
-    red = partial(OpticalBand, 'B3', 'red', resolution=30, wavelength=(0.63, 0.69))
-    nir = partial(OpticalBand, 'B4', 'nir', resolution=30, wavelength=(0.76, 0.9))
-    swir = partial(OpticalBand, 'B5', 'swir', resolution=30, wavelength=(1.55, 1.75))
-    thermal = partial(OpticalBand, 'B6', 'thermal', units='Kelvin', resolution=30, wavelength=(10.4, 12.5))
-    swir2 = partial(OpticalBand, 'B7', 'swir2', resolution=30, wavelength=(2.08, 2.35))
+    blue = partial(OpticalBand, 'B1', 'blue', resolution=30,
+                   wavelength=(0.45, 0.52))
+    green = partial(OpticalBand, 'B2', 'green', resolution=30,
+                    wavelength=(0.52, 0.6))
+    red = partial(OpticalBand, 'B3', 'red', resolution=30,
+                  wavelength=(0.63, 0.69))
+    nir = partial(OpticalBand, 'B4', 'nir', resolution=30,
+                  wavelength=(0.76, 0.9))
+    swir = partial(OpticalBand, 'B5', 'swir', resolution=30,
+                   wavelength=(1.55, 1.75))
+    thermal = partial(OpticalBand, 'B6', 'thermal', units='Kelvin',
+                      resolution=30, wavelength=(10.4, 12.5))
+    swir2 = partial(OpticalBand, 'B7', 'swir2', resolution=30,
+                    wavelength=(2.08, 2.35))
     bqa = BitBand(
         name='BQA', alias='bqa',
-        precision='uint16', resolution=30,
+        precision=Precisions.uint16, resolution=30,
         bits= {
             '4': {1: 'cloud'},
             '5-6': {3: 'high_confidence_cloud'},
@@ -210,10 +222,12 @@ class ETM:
     nir = TM.nir
     swir = TM.swir
     thermal = TM.thermal
-    thermal_vcid_1 = partial(OpticalBand, 'B6_VCID_1', 'B6_vcid_1', units='Kelvin',
-                                 resolution=30, wavelength=(10.4, 12.5))
-    thermal_vcid_2 = partial(OpticalBand, 'B6_VCID_2', 'B6_vcid_2', units='Kelvin',
-                                 resolution=30, wavelength=(10.4, 12.5))
+    thermal_vcid_1 = partial(OpticalBand, 'B6_VCID_1', 'B6_vcid_1',
+                             units='Kelvin', resolution=30,
+                             wavelength=(10.4, 12.5))
+    thermal_vcid_2 = partial(OpticalBand, 'B6_VCID_2', 'B6_vcid_2',
+                             units='Kelvin', resolution=30,
+                             wavelength=(10.4, 12.5))
     swir2 = TM.swir2
     bqa = TM.bqa
     masks = (Mask.fromBand('BQA', bqa),)
@@ -221,20 +235,31 @@ class ETM:
 
 class OLI:
     sensor = 'OLI'
-    aerosol = partial(OpticalBand, 'B1', 'coastal_aerosol', resolution=30, wavelength=(0.43, 0.45))
-    blue = partial(OpticalBand, 'B2', 'blue', resolution=30, wavelength=(0.45, 0.51))
-    green = partial(OpticalBand, 'B3', 'green', resolution=30, wavelength=(0.53, 0.59))
-    red = partial(OpticalBand, 'B4', 'red', resolution=30, wavelength=(0.64, 0.67))
-    nir = partial(OpticalBand, 'B5', 'nir', resolution=30, wavelength=(0.85, 0.88))
-    swir = partial(OpticalBand, 'B6', 'swir', resolution=30, wavelength=(1.57, 1.65))
-    swir2 = partial(OpticalBand, 'B7', 'swir2', resolution=30, wavelength=(2.11, 2.29))
-    pan = partial(OpticalBand, 'B8', 'pan', resolution=15, wavelength=(0.52, 0.9))
-    cirrus = partial(OpticalBand, 'B9', 'cirrus', resolution=15, wavelength=(1.36, 1.38))
-    thermal = partial(OpticalBand, 'B10', 'thermal', resolution=30, scale=0.1, wavelength=(10.60, 11.19))
-    thermal2 = partial(OpticalBand, 'B11', 'thermal2', resolution=30, scale=0.1, wavelength=(11.50, 12.51))
+    aerosol = partial(OpticalBand, 'B1', 'coastal_aerosol',
+                      resolution=30, wavelength=(0.43, 0.45))
+    blue = partial(OpticalBand, 'B2', 'blue',
+                   resolution=30, wavelength=(0.45, 0.51))
+    green = partial(OpticalBand, 'B3', 'green',
+                    resolution=30, wavelength=(0.53, 0.59))
+    red = partial(OpticalBand, 'B4', 'red',
+                  resolution=30, wavelength=(0.64, 0.67))
+    nir = partial(OpticalBand, 'B5', 'nir',
+                  resolution=30, wavelength=(0.85, 0.88))
+    swir = partial(OpticalBand, 'B6', 'swir',
+                   resolution=30, wavelength=(1.57, 1.65))
+    swir2 = partial(OpticalBand, 'B7', 'swir2',
+                    resolution=30, wavelength=(2.11, 2.29))
+    pan = partial(OpticalBand, 'B8', 'pan',
+                  resolution=15, wavelength=(0.52, 0.9))
+    cirrus = partial(OpticalBand, 'B9', 'cirrus',
+                     resolution=15, wavelength=(1.36, 1.38))
+    thermal = partial(OpticalBand, 'B10', 'thermal',
+                      resolution=30, scale=0.1, wavelength=(10.60, 11.19))
+    thermal2 = partial(OpticalBand, 'B11', 'thermal2',
+                       resolution=30, scale=0.1, wavelength=(11.50, 12.51))
     bqa = BitBand(
         name='BQA', alias='bqa',
-        precision='uint16', resolution=30,
+        precision=Precisions.uint16, resolution=30,
         bits= {
             '4': {1: 'cloud'},
             '5-6': {3: 'high_confidence_cloud'},
@@ -245,11 +270,11 @@ class OLI:
     )
 
     class RAW:
-        _extra = dict(precision='uint16')
+        _extra = dict(precision=Precisions.uint16)
 
     class SR:
         aerosol = BitBand('sr_aerosol', 'sr_aerosol',
-                          precision='uint8',
+                          precision=Precisions.uint8,
                           bits= {
                               '1': {1: 'aerosol_valid'},
                               '2': {1: 'aerosol_interpolated'},
@@ -261,7 +286,7 @@ class OLI:
         radsat_qa = BitBand(
             name='radsat_qa',
             alias='radsat_qa',
-            precision='uint16',
+            precision=Precisions.uint16,
             resolution=30,
             bits={
                 1: {1:'B1_saturated'},
@@ -285,8 +310,8 @@ class OLI:
 class Landsat1(MSS, Landsat):
     """ Landsat 1 """
     number = 1
-    start_date = '1975-01-22'
-    end_date = '1978-01-07'
+    start_date = '1972-07-26'
+    end_date = '1978-01-06'
 
 
 @register
@@ -299,8 +324,8 @@ class Landsat1RAW(Tier1, RAW, Landsat1):
     nir = MSS.nir(name='B6', **RAW._extra)
     nir2 = MSS.nir2(name='B7', **RAW._extra)
     bands = (green, red, nir, nir2, MSS.bqa)
-    visualizers = (
-        Visualization.falseColor([nir, red, green]),
+    visualizers = Visualizers(
+        FalseColor = Visualization.falseColor([nir, red, green]),
     )
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
                           [nir, red], precision='float')
@@ -322,8 +347,8 @@ class Landsat1RAWT2(Tier2, Landsat1RAW):
 
 class Landsat2(MSS, Landsat):
     number = 2
-    start_date = '1972-07-23'
-    end_date = '1982-02-26'
+    start_date = '1975-01-31'
+    end_date = '1982-02-03'
 
 
 @register
@@ -351,8 +376,8 @@ class Landsat2RAWT2(Tier2, Landsat2RAW):
 
 class Landsat3(MSS, Landsat):
     number = 3
-    start_date = '1978-03-05'
-    end_date = '1983-03-31'
+    start_date = '1978-06-03'
+    end_date = '1983-02-23'
 
 
 @register
@@ -379,8 +404,8 @@ class Landsat3RAWT2(Tier2, Landsat3RAW):
 
 class Landsat4MSS(MSS, Landsat):
     number = 4
-    start_date = '1982-07-16'
-    end_date = '1993-12-14'
+    start_date = '1982-08-14'
+    end_date = '1992-08-28'
 
 
 @register
@@ -393,8 +418,8 @@ class Landsat4MSSRAW(Tier1, RAW, Landsat4MSS):
     nir = MSS.nir(name='B3', **RAW._extra)
     nir2 = MSS.nir2(name='B4', **RAW._extra)
     bands = (green, red, nir, nir2, MSS.bqa)
-    visualizers = (
-        Visualization.falseColor([nir, red, green]),
+    visualizers = Visualizers(
+        FalseColor = Visualization.falseColor([nir, red, green]),
     )
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
                           [nir, red], precision='float')
@@ -417,8 +442,8 @@ class Landsat4MSSRAWT2(Tier2, Landsat4MSSRAW):
 class Landsat4TM(TM, Landsat):
     """ Landsat 4 TM Raw Tier 1 """
     number = 4
-    start_date = '1982-07-16'
-    end_date = '1993-12-14'
+    start_date = '1982-08-22'
+    end_date = '1993-11-18'
 
 
 @register
@@ -433,10 +458,10 @@ class Landsat4RAW(Tier1, RAW, Landsat4TM):
     thermal = TM.thermal(**RAW._extra)
     swir2 = TM.swir2(**RAW._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, TM.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', TM.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
@@ -471,10 +496,10 @@ class Landsat4TOA(Tier1, TOA, Landsat4TM):
     thermal = TM.thermal(**TOA._extra)
     swir2 = TM.swir2(**TOA._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, TM.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', TM.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
@@ -510,19 +535,19 @@ class Landsat4SR(Tier1, SR, Landsat4TM):
     swir2 = TM.swir2(**SR._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, SR.atm_op,
              SR.sr_cloud_qa, SR.pixel_qa, SR.radsat_qa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red]),
-        SR.atm_op_vis
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red]),
+        AtmosphericOpacity = SR.atm_op_vis
     )
     masks = (Mask.fromBand('pixel_qa', SR.pixel_qa),
              Mask.fromBand('cloud_qa', SR.sr_cloud_qa))
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
 
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -540,8 +565,8 @@ class Landsat4SRT2(Tier2, Landsat4SR):
 
 class Landsat5MSS(MSS, Landsat):
     number = 5
-    start_date = '1984-01-01'
-    end_date = '2012-05-05'
+    start_date = '1984-04-09'
+    end_date = '2013-01-01'
 
 
 @register
@@ -554,8 +579,8 @@ class Landsat5MSSRAW(Tier1, RAW, Landsat4MSS):
     nir = MSS.nir(name='B3', **RAW._extra)
     nir2 = MSS.nir2(name='B4', **RAW._extra)
     bands = (green, red, nir, nir2, MSS.bqa)
-    visualizers = (
-        Visualization.falseColor([nir, red, green]),
+    visualizers = Visualizers(
+        FalseColor = Visualization.falseColor([nir, red, green]),
     )
     masks = (Mask.fromBand('BQA', MSS.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
@@ -579,7 +604,7 @@ class Landsat5MSSRAWT2(Tier2, Landsat5MSSRAW):
 class Landsat5TM(TM, Landsat):
     """ Landsat 5 TM Raw Tier 1 """
     number = 5
-    start_date = '1984-04-16'
+    start_date = '1984-03-16'
     end_date = '2012-05-05'
 
 
@@ -595,16 +620,16 @@ class Landsat5RAW(Tier1, RAW, Landsat5TM):
     thermal = TM.thermal(**RAW._extra)
     swir2 = TM.swir2(**RAW._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, TM.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', TM.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -632,16 +657,16 @@ class Landsat5TOA(Tier1, TOA, Landsat5TM):
     thermal = TM.thermal(**TOA._extra)
     swir2 = TM.swir2(**TOA._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, TM.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', TM.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -670,18 +695,18 @@ class Landsat5SR(Tier1, SR, Landsat5TM):
     swir2 = TM.swir2(**SR._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, SR.atm_op,
              SR.sr_cloud_qa, SR.pixel_qa, SR.radsat_qa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red]),
-        SR.atm_op_vis
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red]),
+        AtmosphericOpacity = SR.atm_op_vis
     )
     masks = (Mask.fromBand('pixel_qa', SR.pixel_qa),
              Mask.fromBand('cloud_qa', SR.sr_cloud_qa))
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -702,6 +727,7 @@ class Landsat7ETM(ETM, Landsat):
     number = 7
     start_date = '1999-05-28'
     end_date = None
+    scl_off = '2003-05-31'
 
 
 @register
@@ -717,16 +743,16 @@ class Landsat7RAW(Tier1, RAW, Landsat7ETM):
     thermal1 = ETM.thermal_vcid_1(**RAW._extra)
     thermal2 = ETM.thermal_vcid_2(**RAW._extra)
     bands = (blue, green, red, nir, swir, thermal1, thermal2, swir2, TM.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', TM.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -755,16 +781,16 @@ class Landsat7TOA(Tier1, TOA, Landsat7ETM):
     thermal1 = ETM.thermal_vcid_1(**TOA._extra)
     thermal2 = ETM.thermal_vcid_2(**TOA._extra)
     bands = (blue, green, red, nir, swir, thermal1, thermal2, swir2, TM.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', TM.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -793,18 +819,18 @@ class Landsat7SR(Tier1, SR, Landsat7ETM):
     swir2 = ETM.swir2(**SR._extra)
     bands = (blue, green, red, nir, swir, thermal, swir2, SR.atm_op,
              SR.sr_cloud_qa, SR.pixel_qa, SR.radsat_qa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red]),
-        SR.atm_op_vis
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red]),
+        AtmosphericOpacity = SR.atm_op_vis
     )
     masks = (Mask.fromBand('pixel_qa', SR.pixel_qa),
              Mask.fromBand('cloud_qa', SR.sr_cloud_qa))
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -844,16 +870,16 @@ class Landsat8RAW(Tier1, RAW, Landsat8OLI):
     thermal2 = OLI.thermal2(**OLI.RAW._extra)
     bands = (aerosol, blue, green, red, nir, swir, swir2, pan, cirrus,
              thermal1, thermal2, OLI.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', OLI.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -886,16 +912,16 @@ class Landsat8TOA(Tier1, TOA, Landsat8OLI):
     thermal2 = OLI.thermal2(**TOA._extra)
     bands = (aerosol, blue, green, red, nir, swir, swir2, pan, cirrus,
              thermal1, thermal2, OLI.bqa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('BQA', OLI.bqa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
@@ -924,18 +950,18 @@ class Landsat8SR(Tier1, SR, Landsat8OLI):
     swir2 = OLI.swir2(**SR._extra)
     thermal1 = OLI.thermal(**SR._extra)
     thermal2 = OLI.thermal2(**SR._extra)
-    bands = (aerosol, blue, green, red, nir, swir, thermal1, thermal2,
+    bands = (aerosol, blue, green, red, nir, swir, swir2, thermal1, thermal2,
              OLI.SR.aerosol, SR.pixel_qa, OLI.SR.radsat_qa)
-    visualizers = (
-        Visualization.trueColor([red, green, blue]),
-        Visualization.falseColor([nir, red, green]),
-        Visualization.NSR([nir, swir, red])
+    visualizers = Visualizers(
+        TrueColor = Visualization.trueColor([red, green, blue]),
+        FalseColor = Visualization.falseColor([nir, red, green]),
+        NSR = Visualization.NSR([nir, swir, red])
     )
     masks = (Mask.fromBand('pixel_qa', SR.pixel_qa),)
     ndvi = ExpressionBand('NDVI', 'ndvi', '(nir-red)/(nir+red)',
-                          [nir, red], precision='float')
+                          [nir, red], precision=Precisions.float)
     nbr = ExpressionBand('NBR', 'nbr', '(nir-swir)/(nir+swir)',
-                         [nir, swir], precision='float')
+                         [nir, swir], precision=Precisions.float)
     extra_bands = (ndvi, nbr)
 
     def __init__(self, **kwargs):
